@@ -2,61 +2,7 @@ use string_enum::StringEnum;
 use swc_atoms::JsWord;
 use swc_common::{ast_node, EqIgnoreSpan, Span};
 
-use crate::{ComplexSelector, SimpleBlock, TokenAndSpan};
-
-#[ast_node]
-pub enum Value {
-    #[tag("SimpleBlock")]
-    SimpleBlock(SimpleBlock),
-
-    #[tag("Dimension")]
-    Dimension(Dimension),
-
-    #[tag("Number")]
-    Number(Number),
-
-    #[tag("Integer")]
-    Integer(Integer),
-
-    #[tag("Percentage")]
-    Percentage(Percentage),
-
-    #[tag("Ratio")]
-    Ratio(Ratio),
-
-    #[tag("Color")]
-    Color(Color),
-
-    #[tag("Ident")]
-    Ident(Ident),
-
-    #[tag("DashedIdent")]
-    DashedIdent(DashedIdent),
-
-    #[tag("String")]
-    Str(Str),
-
-    #[tag("Function")]
-    Function(Function),
-
-    #[tag("CalcSum")]
-    CalcSum(CalcSum),
-
-    #[tag("Delimiter")]
-    Delimiter(Delimiter),
-
-    #[tag("Url")]
-    Url(Url),
-
-    #[tag("UnicodeRange")]
-    UnicodeRange(UnicodeRange),
-
-    #[tag("ComplexSelector")]
-    ComplexSelector(ComplexSelector),
-
-    #[tag("PreservedToken")]
-    PreservedToken(TokenAndSpan),
-}
+use crate::ComponentValue;
 
 #[ast_node("Ident")]
 pub struct Ident {
@@ -108,7 +54,7 @@ pub struct Function {
     /// Span starting from the `lo` of identifier and to the end of `)`.
     pub span: Span,
     pub name: Ident,
-    pub value: Vec<Value>,
+    pub value: Vec<ComponentValue>,
 }
 
 #[ast_node]
